@@ -14,7 +14,6 @@ class ChatLoginDialog : public QDialog
 
 signals:
     void login(QString username, QString password, bool save);
-    void loginCanceled();
 
 public:
     explicit ChatLoginDialog(QWidget *parent = 0);
@@ -22,12 +21,9 @@ public:
 
 private:
     Ui::ChatLoginDialog *ui;
-    bool m_accepted;
-    bool m_isLoggingIn;
 
 private slots:
     void accept();
-    void reject();
 };
 
 #endif // CHATLOGINDIALOG_H
