@@ -352,9 +352,14 @@ void FriendsWindow::onFriendClicked(QListWidgetItem *item)
                 m_checkedIdList.removeOne(id);
         }
     } else {
-        ProfileWindow *window = new ProfileWindow(this, token);
-        window->setAttribute(Qt::WA_DeleteOnClose);
+
+        QPointer<ProfileWindow> window = getWindowById(id);
+        if (window == NULL) {
+            m_profileWindowsById.remove(id);
+            window = getWindowById(id);
+        }
         window->browseProfile(id);
+        window->setAttribute(Qt::WA_DeleteOnClose, false);
         window->setWindowTitle(item->text());
 #ifdef Q_WS_S60
         window->showMaximized();
@@ -364,6 +369,17 @@ void FriendsWindow::onFriendClicked(QListWidgetItem *item)
     }
 }
 
+ProfileWindow* FriendsWindow::getWindowById(QString id)
+{
+    if (!m_profileWindowsById.contains(id)) {
+        ProfileWindow* window = new ProfileWindow(this, token, ProfileWindow::FriendProfile, false);
+        m_profileWindowsById.insert(id, window);
+        return window;
+    } else {
+        return m_profileWindowsById.value(id);
+    }
+}
+
 void FriendsWindow::keyReleaseEvent(QKeyEvent *e)
 {
     if (e->key() == Qt::Key_Enter || e->key() == Qt::Key_Left || e->key() == Qt::Key_Right || e->key() == Qt::Key_Backspace)
