@@ -50,12 +50,14 @@ private:
     Ui::FriendsWindow *ui;
     QString token;
     QFacebook *qfacebook;
+    QMap<QString,ProfileWindow*> m_profileWindowsById;
     QFacebookReply *reply;
     QFacebookReply *pagesReply;
     QNetworkReply *requestsReply;
     QString idToBrowse;
     QNetworkAccessManager *nam;
     FacebookBrowser *browser;
+    ProfileWindow* getWindowById(QString id);
     bool m_isDialog;
     bool m_shouldFetchAvatars;
     bool m_isRequestingFriendList;
