@@ -27,6 +27,8 @@ private:
     QFacebookReply *reply;
     QNetworkAccessManager *nam;
     QString m_userId;
+    QMap<QString,ProfileWindow*> m_profilesMap;
+    ProfileWindow* getProfileWindowForId(QString id);
 
 private slots:
     void updateGroups();
