@@ -24,12 +24,7 @@
 #define appId "133764606703287"
 #endif
 
-/* TODO: Add Android define */
-#if defined (Q_WS_MAEMO_5) || defined (Q_WA_S60)
-    #define authUrl "https://www.facebook.com/dialog/oauth?client_id=%2&redirect_uri=https://www.facebook.com/connect/login_success.html&scope=%1&response_type=token"
-#else
-    #define authUrl "https://www.facebook.com/dialog/oauth?client_id=%2&redirect_uri=https://www.facebook.com/connect/login_success.html&scope=%1&response_type=token"
-#endif
+#define authUrl "https://www.facebook.com/dialog/oauth?client_id=%2&redirect_uri=https://www.facebook.com/connect/login_success.html&scope=%1&response_type=token"
 
 namespace Ui {
     class LoginWindow;
