@@ -1,5 +1,7 @@
 #include <QtGui/QApplication>
 #include <QTime>
+#include <QSsl>
+#include <QSslConfiguration>
 #include "mainwindow.h"
 
 int main(int argc, char *argv[])
@@ -10,6 +12,9 @@ int main(int argc, char *argv[])
 #ifdef Q_WS_MAEMO_5
     QApplication::addLibraryPath("/opt/qtm12/imports");
     QApplication::addLibraryPath("/opt/qtm12/lib");
+    QSslConfiguration config = QSslConfiguration::defaultConfiguration();
+    config.setProtocol(QSsl::TlsV1);
+    QSslConfiguration::setDefaultConfiguration(config);
 #endif
     QApplication a(argc, argv);
 
