@@ -30,6 +30,7 @@
 #include "aboutdialog.h"
 #include "chatwindow.h"
 #include "settingsdialog.h"
+#include "newstatusupdatedialog.h"
 #include "facebookbrowser.h"
 #include <qjson/parser.h>
 
@@ -63,6 +64,7 @@ public slots:
     Q_SCRIPTABLE void top_application();
     Q_SCRIPTABLE void refreshAll();
     Q_SCRIPTABLE void quit();
+    Q_SCRIPTABLE void postUpdate();
 
 protected:
     void closeEvent(QCloseEvent *);
@@ -90,6 +92,7 @@ private:
     QPointer<NotesWindow> notesWindow;
     QPointer<NotificationsDialog> notificationsDialog;
     QPointer<QNetworkAccessManager> nam;
+    QPointer<NewStatusUpdateDialog> m_statusUpdateDialog;
     QNetworkReply *requestsReply;
     QTimer *m_refreshTimer;
     QList<FavoriteItem>favorites;
