@@ -4,6 +4,7 @@
 #include <QMainWindow>
 #include <QSettings>
 #include <QDesktopWidget>
+#include <QPointer>
 #include <qfacebook.h>
 #include "newsfeedpost.h"
 #include "newstatusupdatedialog.h"
@@ -26,7 +27,7 @@ class ProfileWindow : public QMainWindow
 public:
     enum ProfileTypes {FriendProfile,
                        GroupProfile};
-    explicit ProfileWindow(QWidget *parent = 0, QString token = "0", ProfileTypes profileType = FriendProfile);
+    explicit ProfileWindow(QWidget *parent = 0, QString token = "0", ProfileTypes profileType = FriendProfile, bool deleteOnClose = true);
     ~ProfileWindow();
     void browseProfile(QString id);
 
@@ -34,25 +35,26 @@ private:
     Ui::ProfileWindow *ui;
     QString profileId;
     QFacebook *qfacebook;
-    QFacebookReply *reply;
-    QFacebookReply *infoReply;
-    QFacebookReply *postReply;
-    QFacebookReply *friendsReply;
+    QPointer<QFacebookReply> reply;
+    QPointer<QFacebookReply> infoReply;
+    QPointer<QFacebookReply> postReply;
+    QPointer<QFacebookReply> friendsReply;
     QString accessToken;
     QNetworkAccessManager *nam;
-    QList<NewsFeedPost*> posts;
-    QNetworkReply *avatarReply;
+    //QList<NewsFeedPost*> posts;
+    QMap<QString,NewsFeedPost*> posts;
+    QPointer<QNetworkReply> avatarReply;
     QByteArray dataToPost;
     QString m_myId;
+    bool m_deleteOnClose;
     ProfileTypes m_profileType;
     void setAvatar(QPixmap avatar);
+    NewsFeedPost* getPostById(QString id);
 
 private slots:
     void onReplyReceived();
     void onAvatarReceived();
     void onTextBoxClicked();
-    void onPostToWall(QString text, QString link, QString video);
-    void onPosted();
     void updateProfile();
     void onAvatarClicked();
     void onInfoReplyReceived();
