@@ -6,6 +6,11 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QPropertyAnimation>
+#include <QPainter>
+#include <QDebug>
+#include <QFile>
+#include <QDir>
+#include <QDesktopServices>
 
 namespace Ui {
     class NotificationItem;
@@ -23,21 +28,28 @@ public:
     QString userId();
     QString text();
     QString objectType();
+    QString notificationId();
     void setObjectId(QString id);
     void setUserId(QString id);
     void setText(QString text);
+    void setNotificationId(QString notificationId);
     void setObjectType(QString objectType);
     void setUnread(bool);
     bool isUnread();
 
+public slots:
+    void markAsRead();
+
 protected:
     void mousePressEvent(QMouseEvent *);
     void mouseReleaseEvent(QMouseEvent *);
+    void paintEvent(QPaintEvent *);
 
 signals:
     void pressed();
     void released();
     void clicked(NotificationItem *);
+    void markedAsRead(NotificationItem *);
 
 private:
     Ui::NotificationItem *ui;
@@ -45,14 +57,17 @@ private:
     QString m_userId;
     QString m_objectId;
     QString m_objectType;
+    QString m_notificationId;
     bool m_pressed;
     QNetworkAccessManager *nam;
     QNetworkReply *avatarReply;
+    QNetworkReply *m_markAsReadReply;
     bool m_unread;
 
 private slots:
     void onAvatarReceived();
     void getAvatar();
+    void markAsReadReply();
 };
 
 #endif // NOTIFICATIONITEM_H
