@@ -8,7 +8,7 @@ QClickableLabel::QClickableLabel(QWidget *parent) :
 void QClickableLabel::mousePressEvent(QMouseEvent *ev)
 {
     if (ev->button() == Qt::LeftButton) {
-        this->labelPressed = true;
+        m_pressed = true;
         emit pressed();
     }
 }
@@ -16,7 +16,7 @@ void QClickableLabel::mousePressEvent(QMouseEvent *ev)
 void QClickableLabel::mouseReleaseEvent(QMouseEvent *ev)
 {
     if (ev->button() == Qt::LeftButton) {
-        this->labelPressed = false;
+        m_pressed = false;
         emit released();
         if (rect().contains(ev->pos())) {
             emit clicked();
@@ -27,7 +27,7 @@ void QClickableLabel::mouseReleaseEvent(QMouseEvent *ev)
 
 bool QClickableLabel::isPressed()
 {
-    return labelPressed;
+    return m_pressed;
 }
 
 void QClickableLabel::setData(QVariant data)
