@@ -26,7 +26,7 @@ signals:
     void clickedPos(QPoint position);
 
 private:
-    bool labelPressed;
+    bool m_pressed;
     QVariant variant;
 };
 
